@@ -39,8 +39,8 @@
 -- > move =
 -- >  S.map
 -- >    ( proc () -> do
--- >        Velocity v <- Q.fetch -< ()
--- >        Position p <- Q.fetch -< ()
+-- >        Velocity v <- Q.query -< ()
+-- >        Position p <- Q.query -< ()
 -- >        Q.set -< Position $ p + v
 -- >    )
 -- >    >>> S.run print
@@ -50,51 +50,68 @@
 -- > main :: IO ()
 -- > main = runSystem_ $ setup >>> S.forever move
 module Aztecs.ECS
-  ( Access,
-    AccessT,
-    MonadAccess,
-    runAccessT,
-    runAccessT_,
+  ( module Aztecs.ECS.Access,
+    module Aztecs.ECS.System,
     Bundle,
-    MonoidBundle (..),
+    BundleT,
+    bundle,
     DynamicBundle,
     MonoidDynamicBundle (..),
     Component (..),
     EntityID,
     Query,
-    QueryT,
-    QueryReader,
-    QueryReaderF,
-    QueryF,
-    DynamicQueryReaderF,
+    query,
+    queryMaybe,
+    queryMap,
+    queryMapM,
+    queryMapWith,
+    queryMapWith_,
+    queryMapWithM,
     DynamicQueryF,
     QueryFilter,
     with,
     without,
-    System,
-    SystemT,
-    MonadReaderSystem,
-    MonadSystem,
     World,
+
+    -- * Events
+    Event,
+    OnInsert (..),
+    OnChange (..),
+    OnRemove (..),
+
+    -- * Observers
+    Observer,
+    observer,
+    observerFor,
+    observerGlobal,
   )
 where
 
 import Aztecs.ECS.Access
 import Aztecs.ECS.Component (Component (..))
 import Aztecs.ECS.Entity (EntityID)
+import Aztecs.ECS.Event (Event, OnChange (..), OnInsert (..), OnRemove (..))
+import Aztecs.ECS.Observer
+  ( Observer (..),
+    observer,
+    observerFor,
+    observerGlobal,
+  )
 import Aztecs.ECS.Query
   ( DynamicQueryF,
-    DynamicQueryReaderF,
     Query,
-    QueryF,
     QueryFilter,
-    QueryReaderF,
-    QueryT,
+    query,
+    queryMap,
+    queryMapM,
+    queryMapWith,
+    queryMapWithM,
+    queryMapWith_,
+    queryMaybe,
     with,
     without,
   )
-import Aztecs.ECS.Query.Reader (QueryReader)
 import Aztecs.ECS.System
 import Aztecs.ECS.World (World)
-import Aztecs.ECS.World.Bundle (Bundle, MonoidBundle (..))
+import Aztecs.ECS.World.Bundle (Bundle, BundleT, bundle)
 import Aztecs.ECS.World.Bundle.Dynamic (DynamicBundle, MonoidDynamicBundle (..))
